@@ -25,6 +25,8 @@ from kiwi_boxed_plugin.defaults import Defaults
 
 import kiwi_boxed_plugin.defaults as runtime
 
+from kiwi_boxed_plugin.exceptions import KiwiBoxPluginQEMUBinaryNotFound
+
 log = logging.getLogger('kiwi')
 
 
@@ -35,14 +37,20 @@ class BoxBuild:
     Implements an interface to run a kiwi build box using
     the KVM virtualization platform
 
-    :param string boxname: name of the box from kiwi_boxed_plugin.yml
-    :param string arch: arch name for box
+    :param str boxname: name of the box from kiwi_boxed_plugin.yml
+    :param str ram: amount of main memory to use for the box
+    :param str smp: number of CPUs to use in the SMP setup for the box
+    :param str arch: arch name for box
+    :param str machine: machine emulaton type for the box
+    :param str cpu: CPU emulation type
+    :param str sharing_backend: guest/host sharing backend type
     """
     def __init__(
-        self, boxname, ram=None, arch=None, machine=None,
+        self, boxname, ram=None, smp=None, arch=None, machine=None,
         cpu='host', sharing_backend='9p'
     ):
         self.ram = ram
+        self.smp = smp
         self.cpu = cpu
         self.machine = machine
         self.arch = arch or platform.machine()
@@ -104,8 +112,13 @@ class BoxBuild:
             vm_machine.append('accel=kvm')
         vm_machine.append('-cpu')
         vm_machine.append(self.cpu)
+        qemu_binary = self._find_qemu_call_binary()
+        if not qemu_binary:
+            raise KiwiBoxPluginQEMUBinaryNotFound(
+                f'No QEMU binary for {self.arch} found'
+            )
         vm_run = [
-            'qemu-system-{0}'.format(self.arch),
+            qemu_binary,
             '-m', format(self.ram or vm_setup.ram)
         ] + vm_machine + [
         ] + Defaults.get_qemu_generic_setup() + [
@@ -132,7 +145,7 @@ class BoxBuild:
         if vm_setup.initrd:
             vm_run += ['-initrd', vm_setup.initrd]
         if vm_setup.smp:
-            vm_run += ['-smp', format(vm_setup.smp)]
+            vm_run += ['-smp', format(self.smp or vm_setup.smp)]
         os.environ['TMPDIR'] = Defaults.get_local_box_cache_dir()
         log.debug(
             'Set TMPDIR: {0}'.format(os.environ['TMPDIR'])
@@ -158,3 +171,9 @@ class BoxBuild:
             del self.kiwi_build_command[arg_index + 1]
             del self.kiwi_build_command[arg_index]
             return value
+
+    def _find_qemu_call_binary(self):
+        qemu_by_system = Path.which(f'qemu-system-{self.arch}')
+        if qemu_by_system:
+            return qemu_by_system
+        return Path.which('qemu-kvm') if self.arch == 'x86_64' else None
