@@ -19,6 +19,7 @@
 usage: kiwi-ng system boxbuild -h | --help
        kiwi-ng system boxbuild --box=<name>
            [--box-memory=<vmgb>]
+           [--box-smp-cpus=<number>]
            [--box-debug]
            [--kiwi-version=<version>]
            [--shared-path=<path>]
@@ -50,6 +51,10 @@ options:
         Number of GBs to reserve as main memory for the virtual
         machine. By default 8GB will be used.
 
+    --box-smp-cpus=<number>
+        Number of CPUs to use in the SMP setup. By default
+        4 CPUs will be used
+
     --no-update-check
         Skip check for available box update. The option has no
         effect if the selected box does not yet exist on the host.
@@ -152,6 +157,7 @@ class SystemBoxbuildTask(CliTask):
             box_build = BoxBuild(
                 boxname=self.command_args.get('--box'),
                 ram=self.command_args.get('--box-memory'),
+                smp=self.command_args.get('--box-smp-cpus'),
                 arch=self._get_box_arch(),
                 machine=self.command_args.get('--machine'),
                 cpu=self.command_args.get('--cpu') or 'host',
@@ -167,6 +173,7 @@ class SystemBoxbuildTask(CliTask):
             )
 
     def _validate_kiwi_build_command(self):
+        # construct build command from given command line
         kiwi_build_command = [
             'system', 'build'
         ]
@@ -175,15 +182,30 @@ class SystemBoxbuildTask(CliTask):
         )
         if '--' in kiwi_build_command:
             kiwi_build_command.remove('--')
+        # validate build command through docopt from the original
+        # kiwi.tasks.system_build docopt information
         log.info(
             'Validating kiwi_build_command_args:{0}    {1}'.format(
                 os.linesep, kiwi_build_command
             )
         )
-        docopt(
+        validated_build_command = docopt(
             doc=kiwi.tasks.system_build.__doc__,
             argv=kiwi_build_command
         )
+        # rebuild kiwi build command from validated docopt parser result
+        kiwi_build_command = [
+            'system', 'build'
+        ]
+        for option, value in validated_build_command.items():
+            if option.startswith('-') and value:
+                if isinstance(value, bool):
+                    kiwi_build_command.append(option)
+                elif isinstance(value, str):
+                    kiwi_build_command.extend([option, value])
+                elif isinstance(value, list):
+                    for element in value:
+                        kiwi_build_command.extend([option, element])
         final_kiwi_build_command = []
         if self.global_args.get('--type'):
             final_kiwi_build_command.append('--type')
